@@ -65,9 +65,9 @@ my $codeSet = {
 # $processor = Template::Like::Processor->new( $init_option, $params, $option );
 #---------------------------------------------------------------------
 # - args
-# $init_option ... 
+# $init_option ...
 # $params      ... PARAMS ( HASHREF )
-# $option      ... 
+# $option      ...
 #---------------------------------------------------------------------
 # - returns
 # $processor ... Template::Like::Processor Object.
@@ -80,7 +80,7 @@ sub new {
   my $init_option = shift;
   my $params = shift;
   my $option = shift;
-  
+
   my $self = bless {
     OPTION => {
       INCLUDE_PATH       => [],
@@ -103,47 +103,47 @@ sub new {
       WHILE_LIMIT        => 1000
     }
   }, $class;
-  
+
   # ---------- marge option ------------------------------------------
-  
+
   @{ $self->{'OPTION'} }{ keys %{ $init_option } } = values %{ $init_option };
-  
+
   @{ $self->{'OPTION'} }{ keys %{ $option } } = values %{ $option };
-  
+
   for my $key ( ('INCLUDE_PATH', 'LOAD_FILTERS', 'PLUGIN_BASE') ) {
     unless ( UNIVERSAL::isa($self->{'OPTION'}->{ $key }, 'ARRAY') ) {
       $self->{'OPTION'}->{ $key } = [ $self->{'OPTION'}->{ $key } ];
     }
   }
-  
+
   push @{ $self->{'OPTION'}->{'INCLUDE_PATH'} }, File::Spec->curdir();
-  
+
   push @{ $self->{'OPTION'}->{'LOAD_FILTERS'} }, Template::Like::Filters->new;
-  
+
   push @{ $self->{'OPTION'}->{'PLUGIN_BASE'} }, 'Template::Like::Plugin';
-  
+
   if ( not UNIVERSAL::isa($self->{'OPTION'}->{'STASH'}, 'Template::Like::Stash') ) {
     $self->{'OPTION'}->{'STASH'} = Template::Like::Stash->new;
   }
-  
+
   if ( not $self->START_TAG ) {
     $self->{'OPTION'}->{'START_TAG'} = TAG_STYLE_SET->{ $self->TAG_STYLE }->[0];
   }
-  
+
   if ( not $self->END_TAG ) {
     $self->{'OPTION'}->{'END_TAG'} = TAG_STYLE_SET->{ $self->TAG_STYLE }->[1];
   }
-  
+
   # ---------- init stash --------------------------------------------
-  
+
   $self->{'STASH'} = $self->{'OPTION'}->{'STASH'};
-  
+
   $self->stash->update( $params );
-  
+
   $self->stash->update( $self->NAMESPACE );
-  
+
   $self->stash->set( $self->CONSTANT_NAMESPACE, $self->CONSTANTS );
-  
+
   return $self;
 }
 
@@ -167,11 +167,11 @@ sub new {
 #=====================================================================
 sub clone {
   my $self = shift;
-  
+
   my $clone = bless { %{ $self } }, 'Template::Like::Processor';
-  
+
   $clone->{'STASH'} = $self->stash->clone;
-  
+
   return $clone;
 }
 
@@ -184,7 +184,7 @@ sub clone {
 # $buffer = $processor->process( $input );
 #---------------------------------------------------------------------
 # - args
-# $input ... 
+# $input ...
 #---------------------------------------------------------------------
 # - returns
 # $buffer ... String.
@@ -194,7 +194,7 @@ sub clone {
 #=====================================================================
 sub process {
   my $self  = shift;
-  
+
   return $self->execute( $self->compile( $self->load( @_ ) ) );
 }
 
@@ -207,7 +207,7 @@ sub process {
 # $text_ref = $processor->load( $input );
 #---------------------------------------------------------------------
 # - args
-# $input ... 
+# $input ...
 #---------------------------------------------------------------------
 # - returns
 # $text_ref ... Template Text.
@@ -218,28 +218,28 @@ sub process {
 sub load {
   my $self = shift;
   my $data = shift;
-  
+
   # data is filename
   if ( !ref $data ) {
-    
+
     my $filename = $data;
-    
+
     $filename=~s|/{2,}|/|g;
-    
+
     if ( not $self->RELATIVE ) {
       if ( $filename=~/(?:^|\/)\.+\// ) {
         die "[$filename]: relative paths are not allowed (set RELATIVE option) ";
       }
     }
-    
+
     if ( not $self->ABSOLUTE ) {
       if ( File::Spec->file_name_is_absolute($filename) ) {
         die "[$filename]: absolute paths are not allowed (set ABSOLUTE option)";
       }
     }
-    
+
     my $filepath;
-    
+
     if ( File::Spec->file_name_is_absolute($filename) ) {
       $filepath = $filename if -f $filename;
     } else {
@@ -250,31 +250,31 @@ sub load {
         }
       }
     }
-    
+
     die "file not found. filename is [$filename] include_path is ["
       . join(',', $self->INCLUDE_PATH)
       . "]" if not $filepath;
-    
+
     die "file open endless loop [$filepath]"
       if ( exists $self->{'OPEND'}->{ $filepath } && $self->{'OPEND'}->{ $filepath } > 10 );
-    
+
     $self->{'OPEND'}->{ $filepath }++;
-    
+
     my $fh = IO::File->new($filepath) or die "file open failure [$filepath]";
-    
+
     my $input = join '', <$fh>;
     $fh->close;
     return \$input;
   }
-  
+
   elsif ( UNIVERSAL::isa($data, "SCALAR") ) {
     return \do{ my $str = $$data };
   }
-  
+
   elsif ( UNIVERSAL::isa($data, "ARRAY") ) {
     return \do{ my $str = join '', @{$data} };
   }
-  
+
   elsif ( UNIVERSAL::isa($data, "GLOB") ) {
     return \do{ my $str = join '', <$data> };
   }
@@ -300,15 +300,15 @@ sub load {
 sub compile {
   my $self = shift;
   my $text_ref = shift;
-  
+
   my $start = $self->START_TAG;
   my $end   = $self->END_TAG;
-  
+
   my @endTask;
   my $code = '';
-  
+
   no warnings 'uninitialized';
-  
+
   my $appendSet = sub {
     my $directive = shift;
     my $directive_post = $directive . '_POST';
@@ -316,79 +316,79 @@ sub compile {
     $code.= '  ' x scalar( @endTask );
     $code.= sprintf $format, @_;
     $code.= "\n";
-    
+
     if ( exists $codeSet->{ $directive_post } ) {
       push @endTask, sprintf($codeSet->{ $directive_post }, @_);
     }
   };
-  
+
   my $escapeQuote = sub {
     my $str = shift;
     $str=~s/\'/\\\'/g;
     return $str;
   };
-  
+
   while ( $$text_ref=~ s/^(.*?)(?:$start([-=~+]?)(.*?)([-=~+]?)$end)//sx ) {
-    
+
     my ($text, $pre_chomp, $ele, $post_chomp) = ($1, $2, $3, $4);
-    
+
     $text = '' unless defined $text;
     $ele  = '' unless defined $ele;
     $pre_chomp ||= $self->PRE_CHOMP || 0;
     $post_chomp ||= $self->POST_CHOMP || 0;
     $pre_chomp =~ tr/-=~+/1230/;
     $post_chomp =~ tr/-=~+/1230/;
-    
-    if ($pre_chomp == CHOMP_ALL) { 
+
+    if ($pre_chomp == CHOMP_ALL) {
         $text =~ s{ (\n|^) [^\S\n]* \z }{}mx;
-    } elsif ($pre_chomp == CHOMP_COLLAPSE) { 
+    } elsif ($pre_chomp == CHOMP_COLLAPSE) {
         $text =~ s{ (\s+) \z }{ }x;
-    } elsif ($pre_chomp == CHOMP_GREEDY) { 
+    } elsif ($pre_chomp == CHOMP_GREEDY) {
         $text =~ s{ (\s+) \z }{}x;
     }
-    
-    if ($post_chomp == CHOMP_ALL) { 
+
+    if ($post_chomp == CHOMP_ALL) {
       $$text_ref =~ s{ ^ ([^\S\n]* \n) }{}x;
-    } elsif ($post_chomp == CHOMP_COLLAPSE) { 
+    } elsif ($post_chomp == CHOMP_COLLAPSE) {
       $$text_ref =~ s{ ^ (\s+) }{ }x;
-    } elsif ($post_chomp == CHOMP_GREEDY) { 
+    } elsif ($post_chomp == CHOMP_GREEDY) {
       $$text_ref =~ s{ ^ (\s+) }{}x;
     }
-    
+
     $appendSet->( 'TEXT', $escapeQuote->($text) ) if length $text;
-    
-    
+
+
     $ele=~s/^\s+//;
     $ele=~s/\s+$//;
-    
+
     while ( length $ele ) {
-      
+
       my ( $directive, @args );
-      
+
       ( $ele, $directive, @args ) = $self->expansion( $ele );
-      
+
       if ( $directive eq 'END' ) {
         $appendSet->( $directive, ( pop @endTask ) );
       }
-      
+
       elsif ( $directive eq 'ELSE' ) {
         $appendSet->( 'END', ( pop @endTask ) );
         $appendSet->( $directive );
       }
-      
+
       elsif ( $directive eq 'ELSIF' ) {
         $appendSet->( 'END', ( pop @endTask ) );
         $appendSet->( $directive, @args );
       }
-      
+
       else {
         $appendSet->( $directive, @args );
       }
     }
   }
-  
+
   $appendSet->( 'TEXT', $escapeQuote->($$text_ref) ) if length $$text_ref;
-  
+
   return "{\n$code}\n";
 }
 
@@ -397,7 +397,7 @@ sub insert {
   ${ shift->load(@_) };
 }
 
-# 
+#
 sub include {
   shift->clone->process(@_);
 }
@@ -406,24 +406,24 @@ sub plugin_use {
   my $self = shift;
   my $key  = shift;
   my $plugin_name = $key;
-  
+
   if ($key=~/(.*)=(.*)/){
     $key = $1;
     $plugin_name = $2;
   }
-  
+
   for my $base ( $self->PLUGIN_BASE ) {
-    
+
     my $plugin_class = $base.'::'.$plugin_name;
-    
-    UNIVERSAL::can($plugin_class, 'can') || eval "use $plugin_class;";
-    
+
+    eval "use $plugin_class;";
+
     unless ($@) {
       $self->stash->set( $key, $plugin_class->new($self, @_) );
       return;
     }
   }
-  
+
   die ($@) if ($@);
 }
 
@@ -433,45 +433,45 @@ sub plugin_use {
 sub expansion {
   my $self       = shift;
   my $expression = shift;
-  
+
   my ( $directive, @pre_opts, @post_opts );
-  
+
   # -----------------------------------------------------------------
-  
+
   if ( $expression=~s/^(CALL|GET|SET|IF|UNLESS|ELSIF|DUMMY|PRE_SPACE|POST_SPACE)\s+//x ) {
     $directive  = $1;
   }
-  
+
   # USE
   elsif ( $expression=~s/^USE\s+// ) {
-    
+
     $directive = 'USE';
     my $key  = '';
     my $code = '';
     my @gets = '';
     my $text = '';
-    
+
     # SET
     if ( $expression=~s/^(\w+)\s*=\s*// ) {
       $key  = $1.'=';
     }
-    
+
     # ARGUMENTS
     if ( $expression=~s/^([a-zA-Z0-9\.]+)// ) {
       $text = $1;
     }
-    
+
     @pre_opts = ( $key.$text );
   }
-  
+
   elsif ( $expression=~/^(FILTER|INSERT|INCLUDE)\s+(\S.*)$/sx ) {
-    
+
     $directive = $1;
     $expression = $2;
-    
+
     if ($expression=~s/^\$//) {
     }
-    
+
     else {
       if ($expression=~s/([^\(\);\s]+)//) {
         my $name = $1;
@@ -480,42 +480,42 @@ sub expansion {
       }
     }
   }
-  
+
   # ELSE
   elsif ( $expression=~s/ELSE// ) {
     $directive = 'ELSE';
   }
-  
+
   # END
   elsif ( $expression=~s/END// ) {
     $directive = 'END';
   }
-  
+
   # FOREACH
   elsif ( $expression=~s/^FOREACH\s*(\w+)\s*(?:\=|IN)\s*// ) {
     $directive = 'FOREACH';
     @post_opts = ($1);
   }
-  
+
   # WHILE (?:(\w+)\s*\=\s*)?
   elsif ( $expression=~s/^WHILE\s*// ) {
     $directive = 'WHILE';
   }
-  
+
   # OTHER
   else {
     $directive = 'GET';
   }
-  
-  
+
+
   # -----------------------------------------------------------------
-  
-  
+
+
   my $token;
   my $code = '';
   my $depth = 0;
   my $start = { 0 => 0 };
-  
+
   while ($expression =~
     s/
       # strip out any comments
@@ -568,49 +568,49 @@ sub expansion {
         |   \s+                    # something unquoted
         )                          # end of $11
     //mxo) {
-    
+
     if (defined ($token = $3)) {
       $code.= $2 . $token . $2;
     }
-    
+
     elsif (defined ($token = $4)) {
       $code.= $token;
     }
-    
+
     elsif (defined ($token = $5)) {
       $token=~s/\'/\\\'/g;
       $code.= "'$token'";
     }
-    
+
     elsif (defined ($token = $6)) {
       $code = sprintf q{$self->filter('%s', %s, }, $token, $code;
       $depth++;
     }
-    
+
     elsif (defined ($token = $7)) {
       $code = sprintf q{$self->filter('%s', %s)}, $token, $code;
     }
-    
+
     elsif (defined ($token = $8)) {
       # method after dot.
       if ( $token=~/^\./ && $code=~/\)$/ ) {
         $token = substr($token, 1);
-        substr($code, $start->{ $depth }) = 
+        substr($code, $start->{ $depth }) =
           '$stash->next(' . substr($code, $start->{ $depth }) . ", '$token', ";
       }
-      
+
       # first dollar.
       elsif ( $token=~/^\$(.*)$/ ) {
         $start->{ $depth } = length $code;
         $code.= "\$stash->get('$1', ";
       }
-      
+
       # first dot.
       elsif ( $token=~/^\.(.*)$/ ) {
         substr($code, $start->{ $depth }) =
           '$stash->next(' . substr($code, $start->{ $depth }) . ", '$1', ";
       }
-      
+
       # directive which can omit the dollar.
       else {
         $start->{ $depth } = length $code;
@@ -618,68 +618,68 @@ sub expansion {
       }
       $depth++;
     }
-    
+
     elsif (defined ($token = $9) && $directive eq 'USE') {
-      
+
       $code.= "$token =>";
     }
-    
+
     elsif (defined ($token = $9)) {
-      
+
       if ( $directive eq 'GET' ) {
         $directive = 'SET';
       }
-      
+
       # method after dot.
       if ( $token=~/^\./ && $code=~/\)$/ ) {
         $token = substr($token, 1);
         $code.= "->{'$token'} =";
       }
-      
+
       # first dollar.
       elsif ( $token=~/^\$(.*)$/ ) {
         $code.= "\$stash->{'$1'} =";
       }
-      
+
       # first dot.
       elsif ( $token=~/^\.(.*)$/ ) {
         $code.= "->{'$1'} =";
       }
-      
+
       else {
         $code.= "\$stash->{'$token'} =";
       }
-      
+
 #      $start->{ $depth } = length $code;
     }
-    
+
     elsif (defined ($token = $10)) {
-      
+
       # method after dot.
       if ( $token=~/^\./ && $code=~/\)$/ ) {
         $token = substr($token, 1);
         substr($code, $start->{ $depth }) =
           '$stash->next(' . substr($code, $start->{ $depth }) . ", '$token')";
       }
-      
+
       # first dollar.
       elsif ( $token=~/^\$(.*)$/ ) {
         $start->{ $depth } = length $code;
         $code.= "\$stash->get('$1')";
       }
-      
+
       # first dot.
       elsif ( $token=~/^\.(.*)$/ ) {
         substr($code, $start->{ $depth }) =
           '$stash->next(' . substr($code, $start->{ $depth }) . ", '$1')";
       }
-      
+
       else {
         $start->{ $depth } = length $code;
         $code.= "\$stash->get('$token')";
       }
     }
-    
+
     elsif (defined ($token = $11)) {
       if ( $token eq '==' ) {
         $code.= ' eq ';
@@ -696,13 +696,13 @@ sub expansion {
         $code.= $token;
       }
     }
-    
+
 #    warn "depth: " . $depth;
 #    warn "start: " . $start->{ $depth };
 #    warn "token: $token";
 #    warn "code: " . $code . "\n";
   }
-  
+
   return ( $expression, $directive, @pre_opts, $code, @post_opts );
 }
 
@@ -726,17 +726,17 @@ sub expansion {
 sub filter {
   my $self = shift;
   my $name = shift;
-  
+
   if ( exists $self->FILTERS->{ $name } ) {
     return $self->FILTERS->{ $name }->( @_ );
   }
-  
+
   for my $filter ( $self->LOAD_FILTERS ) {
     if ( UNIVERSAL::can($filter, $name) ) {
       return $filter->$name( @_ );
     }
   }
-  
+
   die "not defined filter [$name].";
 }
 
@@ -760,16 +760,16 @@ sub filter {
 sub execute {
   my $self = shift;
   my $code = shift;
-  
+
   my $output = '';
   my $stash = $self->stash;
-  
+
   warn $code if $self->DEBUG;
-  
+
   no warnings 'uninitialized';
   eval $code;
   die sprintf("Template::Like Error: %s\ncode: \n%s", $@, $code) if $@;
-  
+
   return $output;
 }
 
@@ -793,47 +793,47 @@ sub finalize {
   my $self   = shift;
   my $buffer = shift;
   my $output = shift;
-  
+
   if ( ref $output ) {
-    
+
     if ( UNIVERSAL::isa($output, 'SCALAR') ) {
       ${ $output }.= $buffer;
     }
-    
+
     elsif ( UNIVERSAL::isa($output, 'ARRAY') ) {
       push @{ $output }, $buffer;
     }
-    
+
     elsif ( UNIVERSAL::isa($output, 'CODE') ) {
       $output->($buffer);
     }
-    
+
     # filehandle
     elsif ( UNIVERSAL::isa($output, 'GLOB') ) {
       print $output $buffer;
     }
-    
+
     # Apache::Request, Apache2::Request ...
     elsif ( UNIVERSAL::can($output, 'print') ) {
       $output->print($buffer);
     }
-    
+
     else {
       die "no support output [$output]";
     }
   }
-  
+
   # filename
   else {
-    
+
     my $path =   $self->OUTPUT_PATH
                ? File::Spec->catfile( $self->OUTPUT_PATH, $output )
                : $output;
-    
+
     my $mark = -f $path ? '+<' : '>';
     my $fh = new IO::File $mark.$path
       or $self->error("output file open failure [".$path."]");
-    
+
     seek $fh, 0, 0;
     print $fh $buffer;
     truncate $fh, tell($fh);
